@@ -3,13 +3,6 @@ use Moose;
 
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome';
 
-override _build_WriteMakefile_args => sub {
-   shift->zilla->distmeta->{dynamic_config} = 1;
-   +{
-      %{ super() },
-   }
-};
-
 override _build_WriteMakefile_dump => sub {
    my ($self) = @_;
    my $txt = super();
@@ -42,10 +35,16 @@ sub os_deps {
       return ( 'VMS::Process' => 0 );
    }
    else {
-      if ( not -d '/proc' ) {
+      # let's hope they have /proc
+      if ( -d '/proc' and @{[ glob('/proc/*') ]} ) {
+         return ();
+      }
+      # ...or that Proc::ProcessTable can handle it
+      else {
          return ( 'Proc::ProcessTable' => 0.48 );  # ie: the one that ain't broke
       }
    }
+   return ();
 }
 TEMPLATE
 
